volnmf_simplex_col finds non-negative matrix C that minimizes the objective ||X-C*R||^2
under constraints that columns of C equal to 1 using local approximation with extrapolation.
volnmf_simplex_col(
X,
R,
C.prev = NULL,
bound = 1,
extrapolate = TRUE,
err.cut = 1e-10,
n.iter = 10000,
qmax = 100
)Numeric Matrices. Matrices involved in the objective function.
Numeric Matrices. Matrices involved in the objective function.
Numeric Matrices. Matrices involved in the objective function. Matrix C.prev serves as initialization. (default=NULL)
A numeric. Equality constraint on columns of matrix C. (default=1)
A boolean. Use extrapolation after local approximation. (default=TRUE)
A numeric. Stop iterations if relative error between iterations is less than err.cut (parameter is not active now). (default=1e-10)
An integer. Number of iterations. (default=1000)
A numeric. Maximum asymptotic (1 - 1/qmax) of extrapolation step.
An updated matrix C.